### ￥{LanguageCode:7001}￥

￥{LanguageCode:7002}￥ | ￥{LanguageCode:7003}￥
--- | ---
￥{LanguageCode:7004}￥ | {VERSION}
￥{LanguageCode:7005}￥ | {WORKDIR}

### ￥{LanguageCode:7006}￥

￥{LanguageCode:7002}￥ | ￥{LanguageCode:7003}￥
--- | ---
￥{LanguageCode:7007}￥ | cyrxdzj
￥{LanguageCode:7008}￥ | https://gitee.com/cyrxdzj/PyCheer
￥{LanguageCode:7009}￥ | MulanPSL-2.0

### ￥{LanguageCode:7010}￥

￥{LanguageCode:7011}￥ | ￥{LanguageCode:7012}￥ | ￥{LanguageCode:7013}￥
--- | --- | ---
Flask | BSD 3-Clause "New" or "Revised" License | 服务端的服务框架。
Ace | BSD开源许可证 | 用于代码编辑区域。
Axios | MIT License | 用于浏览器向服务端发起请求。
Bootstrap | MIT License | 用于界面UI。
jQuery | MIT License | 支撑Bootstrap运行。
lottie-player | MIT License | 用于提供动画。
SweetAlert | MIT License | 用于弹出对话框。
Markdown*Palettes | （未指定） | 用于Markdown编辑器。